/*****************************************************************************
 * Apci32w.h
 *
 * aPCI-P32
 * Copyright (C) ADTEK SYSTEM SCIENCE Co.,Ltd.
 *****************************************************************************/
#pragma once

using namespace System;
using namespace System::ComponentModel;
using namespace System::Collections;
using namespace System::Windows::Forms;
using namespace System::Data;
using namespace System::Drawing;
using namespace System::Threading;
using namespace System::Runtime::InteropServices;

static int mErrWradll;	// bp[֐G[

public class Apci32w
{
public:
	/*==================*/
	/*	Error Code		*/
	/*==================*/
	static const int	SUCCESS					= 0;	/* Successfully proccessed */
	static const int	ERR_SYSTEM				= 1;	/* Call GetLastError() */
	static const int	ERR_NO_DEVICE			= 2;	/* No card */
	static const int	ERR_IN_USE				= 3;	/* Device is in use */
	static const int	ERR_INVALID_SLOT		= 4;	/* Invalid slot number */
	static const int	ERR_RESOURCE			= 5;	/* Resource exhaustion */
	static const int	ERR_INVALID_PORT		= 6;	/* Invalid port */
	static const int	ERR_INVALID_ARGUMENT	= 7;	/* Invalid argument */
	static const int	ERR_NO_CREATE			= 8;	/* No created device */
	static const int	ERR_WRAPDLL				= -1;	// bp[֐G[

	/*==========================================*/
	/*	aPCI-P32 card's relative port address	*/
	/*==========================================*/
	static const int	PORT_1					= 0;
	static const int	PORT_2					= 1;
	static const int	PORT_3					= 2;
	static const int	PORT_4					= 3;
	static const int	PORT_5					= 4;
	static const int	PORT_6					= 5;
	static const int	PORT_7					= 6;
	static const int	PORT_8					= 7;

	/*==================*/
	/*	Miscellaneous	*/
	/*==================*/
	static const int	MAX_SLOTS				= 16;	/* Maximum number of slots */
	static const int	MAX_PORTS				= 4;	/* Maximum number of user ports */

	static const short	SLOT_AUTO				= -1;	/* default search */

	/*==================================*/
	/*	Resource infomation structure	*/
	/*==================================*/
	static const int	MAX_MEM					= 9;
	static const int	MAX_IO					= 20;
	static const int	MAX_IRQ					= 7;
	static const int	MAX_DMA					= 7;
	static const int	MAX_RSV					= 3;

	struct Resource {
		int	dwNumMemWindows;
		int dwMemBase[Apci32w::MAX_MEM];
		int dwMemLength[Apci32w::MAX_MEM];
		int dwMemAttrib[Apci32w::MAX_MEM];
		int	dwNumIOPorts;
		int dwIOPortBase[Apci32w::MAX_IO];
		int dwIOPortLength[Apci32w::MAX_IO];
		int dwNumIRQs;
		int dwIRQRegisters[Apci32w::MAX_IRQ];
		int dwIRQAttrib[Apci32w::MAX_IRQ];
		int dwNumDMAs;
		int dwDMALst[Apci32w::MAX_DMA];
		int dwDMAAttrib[Apci32w::MAX_DMA];
		int dwReserved1[Apci32w::MAX_RSV];
	};

	/*==================*/
	/*	API Functions	*/
	/*==================*/
	[DllImport("apci32.dll")]
	static bool Apci32GetVersion( int* pdwDllVersion, int* pdwDriverVersion );
	[DllImport("apci32.dll")]
	static bool Apci32Create( short* pwLogSlot );
	[DllImport("apci32.dll")]
	static bool Apci32Close( short wLogSlot );
	[DllImport("apci32.dll")]
	static bool Apci32GetResource( short wLogSlot, Resource* pres );
	[DllImport("apci32.dll")]
	static bool Apci32GetSwitchValue( short wLogSlot, int* pdwSwitchValue );
	[DllImport("apci32.dll")]
	static bool Apci32InPort( short wLogSlot, int dwLogPort, Byte* pbInValue );
	[DllImport("apci32.dll")]
	static bool Apci32GetLastError( short wLogSlot );

	/*============================================================================
	// 	  aPCI-P32 DLL,޲ײްްޮݔԍ擾
	// 	  pdwDllVersion		DLLްޮݔԍi[̈ւ߲
	//		  pdwDriverVersion	޲ײްްޮݔԍi[̈ւ߲
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool GetVersion(int* pdwDllVersion, int* pdwDriverVersion)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci32GetVersion(pdwDllVersion, pdwDriverVersion);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-P32 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}
	/*============================================================================
	// 	  aPCI-P32̔Cӂ޲̎gp錾
	// 	  pwLogSlot	 gp޲̘_ۯĔԍi[߲
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool Create(short* pwLogSlot)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci32Create(pwLogSlot);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-P32 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}
	/*============================================================================
	// 	  aPCI-P32̔Cӂ޲̎gpJ
	// 	  wLogSlot ޲̘_ۯĔԍ
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool Close(short wLogSlot)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci32Close(wLogSlot);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-P32 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}
	/*============================================================================
	// 	  w޲ؿ擾
	// 	  wLogSlot	ؿ擾޲̘_ۯĔԍ
	//		  pResInfo	ؿi[\߲̂
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool GetResource(short wLogSlot, Resource* pResInfo)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci32GetResource(wLogSlot, pResInfo);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-P32 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}
	/*============================================================================
	// 	  Cӂ߰Ăް
	// 	  wLogSlot	͂޲̘_ۯĔԍ
	//		  dwLogPort	͂_߰
	//		  pbInValue ްi[̈ւ߲
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool InPort(short wLogSlot, int dwLogPort, Byte* pbInValue)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci32InPort(wLogSlot, dwLogPort, pbInValue);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-P32 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}
	/*============================================================================
	// 	  aPCI-P32̴װ
	// 	  wLogSlot	װ޲̘_ۯĔԍ
	// ߂l װ
	//==========================================================================*/
	static int GetLastError(short wLogSlot)
	{
		try {
			if (mErrWradll == ERR_WRAPDLL) {	// bp[֐G[Ȃ
				mErrWradll = SUCCESS;			// NA
				return ERR_WRAPDLL;
			} else {
				return Apci32GetLastError(wLogSlot);
			}
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-P32 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = SUCCESS;	// bp[֐G[
			return ERR_WRAPDLL;
		}
	}
	/*============================================================================
	// 	  ۰ذ̒l擾
	//    wLogSlot			۰ذ̒l擾޲̘_ۯĔԍ
	// 		  pdwSwitchValue	۰ذ̒li[̈ւ߲
	// ߂l  true
	//		  s false
	//==========================================================================*/
	static bool GetSwitchValue(short wLogSlot, int* pdwSwitchValue)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci32GetSwitchValue(wLogSlot, pdwSwitchValue);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-P32 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}

};
