/************************************************************************/
/*		aPCI-P32 Device Driver for Windows 95/NT						*/
/*																		*/
/*			apc32.h	-	Win32 interface definition		    			*/
/*			date		-	1999/06/04									*/
/************************************************************************/

#if !defined( APCI32_H )
#define	APCI32_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	APCI32_SUCCESS					0	/* Successfully proccessed */
#define	APCI32_ERR_SYSTEM				1	/* Call GetLastError() */
#define	APCI32_ERR_NO_DEVICE			2	/* No card */
#define	APCI32_ERR_IN_USE				3	/* Device is in use */
#define	APCI32_ERR_INVALID_SLOT	    	4	/* Invalid slot number */
#define	APCI32_ERR_RESOURCE		     	5	/* Resource exhaustion */
#define	APCI32_ERR_INVALID_PORT		    6	/* Invalid port */
#define	APCI32_ERR_INVALID_ARGUMENT     7	/* Invalid argument */
#define	APCI32_ERR_NO_CREATE			8	/* No created device */

/*==========================================*/
/*	aPCI-P32 card's relative port address	*/
/*==========================================*/
#define	APCI32_PORT_1	0
#define	APCI32_PORT_2	1
#define	APCI32_PORT_3	2
#define	APCI32_PORT_4	3
#define	APCI32_PORT_5	4
#define	APCI32_PORT_6	5
#define	APCI32_PORT_7	6
#define	APCI32_PORT_8	7

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	APCI32_MAX_SLOTS	16			/* Maximum number of slots */
#define APCI32_MAX_PORTS	8			/* Maximum number of user ports */

										/* default search */
#define	APCI32_SLOT_AUTO		( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	APCI32_BOARD_ID	0x9132		/* pci bus device id */
#define	APCI32_VENDOR_ID	0x136c		/* pci bus vendor id */
										/* our device id */
#define	APCI32_DEVICE_ID	( ( DWORD )APCI32_BOARD_ID\
							| ( ( DWORD )APCI32_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	APCI32_MAX_MEM		9			/* number of memory windows */
#define	APCI32_MAX_IO		20			/* number of i/o windows */
#define	APCI32_MAX_IRQ		7			/* number of irqs */
#define	APCI32_MAX_DMA		7			/* number of dmas */

typedef	struct	_APCI32RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[APCI32_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[APCI32_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[APCI32_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[APCI32_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[APCI32_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Not used */
	DWORD	dwIRQRegisters	[APCI32_MAX_IRQ];	/* Not used */
	DWORD	dwIRQAttrib		[APCI32_MAX_IRQ];	/* Not used */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[APCI32_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[APCI32_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} APCI32RESOURCE, *PAPCI32R;

#if !defined( APCI32_DRIVER )
#define	APCI32_API

#if !defined( APCI32_DLL )
	#define APCI32LIB_API	extern __declspec( dllimport )
#else
	#define APCI32LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

APCI32LIB_API BOOL	WINAPI	Apci32GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
APCI32LIB_API BOOL	WINAPI	Apci32Create( PWORD pwLogSlot );
APCI32LIB_API BOOL	WINAPI	Apci32Close( WORD wLogSlot );
APCI32LIB_API BOOL	WINAPI	Apci32GetResource( WORD wLogSlot, PAPCI32R pres );
APCI32LIB_API BOOL	WINAPI	Apci32GetSwitchValue( WORD wLogSlot, PDWORD pdwSwitchValue );
APCI32LIB_API BOOL	WINAPI	Apci32InPort( WORD wLogSlot, DWORD dwLogPort, PBYTE pbInValue );
APCI32LIB_API DWORD	WINAPI	Apci32GetLastError( WORD wLogSlot );

#endif	/* #if !defined( APCI32_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( APCI32_H ) */

/**/